# baserelease defines which build revision of this version we're building.
# The magical name baserelease is matched by the rpmdev-bumpspec tool, which
# you should use.
%global baserelease 5

# On a prerelease version set this settings to the selected date and commit,
# to switch to a released version set them to 0.
%global prerelease_date 0
%global prerelease_timestamp 0

# pkg_release is what we'll fill in for the rpm Release: field
%if 0%{?prerelease_date}%{?prerelease_timestamp}
    %define pkg_release 0.%{baserelease}.%{prerelease_date}snap%{?dist}
%else
    %define pkg_release %{baserelease}%{?dist}
%endif

Name:           scilab
Version:        5.4.1
Release:        %{pkg_release}
Summary:        Scientific software package for numerical computations

Group:          Applications/Engineering
License:        CeCILL
URL:            http://www.scilab.org/
%if 0%{?prerelease_date}%{?prerelease_timestamp}
Source0:        http://downloadarea.scilab.org/download/%(date -d%{prerelease_date} +%%Y-%%m-%%d)/scilab-master-%{prerelease_timestamp}-src.tar.gz
%else
Source0:        http://www.scilab.org/download/%{version}/scilab-%{version}-src.tar.gz
%endif

# Bug 767102 - help() should suggest scilab-doc
Patch1:         %{name}-0001-Use-pkcon-to-install-doc-package.patch
# Bug 64307 - Use dynamic stack on 32-bit to avoid miscompilation
# http://bugzilla.scilab.org/show_bug.cgi?id=12625
Patch2:         %{name}-0002-always-use-dynamic-stack.patch
# Backport upgrade to matio 1.5
Patch3:         %{name}-0003-upgrade-to-matio-1.5.patch

# Dependencies are extracted from :
# "http://wiki.scilab.org/Dependencies of Scilab 5.X"

# Mandatory
BuildRequires:  gcc-gfortran

## for dynamic link features
Requires:       gcc
Requires:       gcc-c++
Requires:       gcc-gfortran

# Core
BuildRequires:  libxml2-devel
BuildRequires:  pcre-devel
BuildRequires:  ncurses-devel

# Numerical libraries
# see "http://wiki.scilab.org/Linalg performances"
BuildRequires:  lapack-devel
BuildRequires:  arpack-devel

# GUI/Console
BuildRequires:  jpackage-utils
BuildRequires:  java-devel
BuildRequires:  ant

BuildRequires:  flexdock
BuildRequires:  scirenderer
BuildRequires:  jogl2
BuildRequires:  mesa-libGL-devel

Requires:       flexdock
Requires:       scirenderer
Requires:       jogl2

BuildRequires:  jrosetta
Requires:       jrosetta

BuildRequires:  apache-commons-logging
BuildRequires:  javahelp2
BuildRequires:  jlatexmath
BuildRequires:  jlatexmath-fop
BuildRequires:  jgraphx
BuildRequires:  fop
BuildRequires:  jeuclid
BuildRequires:  batik
BuildRequires:  xmlgraphics-commons

Requires:       apache-commons-logging
Requires:       javahelp2
Requires:       jlatexmath
Requires:       jlatexmath-fop
Requires:       jgraphx
Requires:       fop
Requires:       jeuclid
Requires:       batik
Requires:       xmlgraphics-commons

# TCL/TK features
BuildRequires:  tcl-devel
BuildRequires:  tk-devel

Requires:       tcl
Requires:       tk
Requires:       bwidget

# Modelica
BuildRequires:  ocaml

# Documentation
BuildRequires:  saxon
BuildRequires:  docbook-style-xsl
BuildRequires:  liberation-sans-fonts

# QA tests and validation
BuildRequires:  checkstyle
BuildRequires:  junit4
BuildRequires:  cobertura

# All optional dependencies are needed to provide a full-featured Scilab
BuildRequires:  gettext-devel
BuildRequires:  fftw-devel
BuildRequires:  matio-devel
BuildRequires:  suitesparse-devel
BuildRequires:  hdf5-devel

# hdf5 does not bump soname but check at runtime
Requires:       hdf5 = %{_hdf5_version}

# Specific dependencies for packaging purpose
BuildRequires:  desktop-file-utils

%description
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

%package devel
Group:          Applications/Engineering
License:        CeCILL

Summary:        Scientific software package for numerical computations (include files)

Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide include files for Scilab.

%package doc
Group:          Documentation
License:        CeCILL

Summary:        Scientific software package (documentation files)

BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description doc
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide documentation files for Scilab.

%package tests
Group:          Applications/Engineering
License:        CeCILL

Summary:        Provides test files for Scilab

BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}
Requires:       testng

%description tests
Scilab is the free software for numerical computation providing a powerful
computing environment for engineering and scientific applications. It
includes hundreds of mathematical functions. It has a high level programming
language allowing access to advanced data structures, 2-D and 3-D graphical
functions.

This package provide test files for Scilab.

%prep
%if 0%{?prerelease_date}%{?prerelease_timestamp}
%setup -q -n scilab-master-%{prerelease_timestamp}
%else
%setup -q
%endif

%patch1 -p2 -b .pkgcon
%patch2 -p1 -b .stack
%patch3 -p2 -b .matio

# Update saxon dependency
# http://bugzilla.scilab.org/show_bug.cgi?id=8479
sed -i "s/com.icl.saxon.Loader/net.sf.saxon.Version/g" m4/docbook.m4 configure
rm modules/helptools/src/java/org/scilab/modules/helptools/BuildDocObject.java

# Fix Class-Path in manifest
sed -i '/name="Class-Path"/d' build.incl.xml

# Fix file-not-utf8
iconv -f ISO_8859-1 -t UTF-8 COPYING >COPYING.utf8
mv COPYING.utf8 COPYING

%build
%configure

make %{?_smp_mflags}
make %{?_smp_mflags} doc

%install
make %{?_smp_mflags} install DESTDIR=%{buildroot}
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop
%find_lang %{name}

# Remove more advanced repl, user should use CLI options instead
rm -fr %{buildroot}%{_datadir}/applications/%{name}-*.desktop
# Remove la files
rm -fr %{buildroot}%{_libdir}/%{name}/*.la

# fix non-executable-script
chmod +x %{buildroot}%{_datadir}/%{name}/modules/helptools/bin/*

# Add localized help files to scilab-doc.lang
# adapted from find-lang.sh
# always provide the english help to handle missing localized help pages
find %{buildroot}%{_datadir}/%{name}/modules/helptools/jar -type f -o -type l|sed '
s:'"%{buildroot}"'::
s:\(.*/'"%{name}"'_\)\([^\._]\+\)\(.*\.jar$\):%lang(\2) \1\2\3:
s:^\([^%].*\)::
s:%lang(en) ::
s:%lang(C) ::
/^$/d' |tee %{name}-doc.lang

%check
make check-TESTS

%post
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f %{name}.lang
%defattr(-,root,root,-)
%doc README_Unix COPYING license.txt
%{_bindir}/*
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/icons/*/*/*/*.png
%{_datadir}/mime/packages/%{name}.xml
# part of scilab-devel
%exclude %{_datadir}/%{name}/contrib
%exclude %{_datadir}/%{name}/tools
# part of scilab-doc
%exclude %{_datadir}/%{name}/modules/helptools/jar/%{name}_*.jar
%exclude %{_datadir}/%{name}/modules/*/examples
%exclude %{_datadir}/%{name}/modules/*/help
%exclude %{_datadir}/%{name}/modules/*/javadoc
# part of scilab-tests
%exclude %{_datadir}/%{name}/modules/*/tests

%files devel
%defattr(-,root,root,-)
%doc README_Unix COPYING license.txt
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/contrib
%{_datadir}/%{name}/tools

%files doc -f %{name}-doc.lang
%defattr(-,root,root,-)
%doc README_Unix COPYING license.txt
%{_datadir}/doc/%{name}-*
%{_datadir}/%{name}/modules/*/examples
%{_datadir}/%{name}/modules/*/help
%{_datadir}/%{name}/modules/*/javadoc

%files tests
%defattr(-,root,root,-)
%doc README_Unix COPYING license.txt
%{_datadir}/%{name}/modules/*/tests

%changelog
* Wed Nov 06 2013 Clément David <c.david86@gmail.com> - 5.4.1-5
- Add the bwidget dependency

* Mon May 20 2013 Clément David <c.david86@gmail.com> - 5.4.1-4
- Enable matio 1.5
- Add some optional (QA) dependencies

* Fri May 17 2013 Orion Poplawski <orion@cora.nwra.com> - 5.4.1-3
- Add patch to fix i686 build by using dynamic stack

* Fri May 17 2013 Clément David <c.david86@gmail.com> - 5.4.1-3
- Fix the build, i686 built had failures on macro generation.

* Thu May 16 2013 Orion Poplawski <orion@cora.nwra.com> - 5.4.1-2
- Rebuild for hdf5 1.8.11

* Fri Mar 29 2013 Clément David <c.david86@gmail.com> - 5.4.1-1
- Update to 5.4.1
- disable matio 1.5

* Thu Feb 21 2013 Clément David <c.david86@gmail.com> - 5.4.0-4
- Remove the jdf5 dependency

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.4.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Dec 05 2012 Orion Poplawski <orion@cora.nwra.com> - 5.4.0-2
- Rebuild for hdf5 1.8.10

* Tue Oct 30 2012 Clément David <c.david86@gmail.com> - 5.4.0-1
- Update to 5.4.0

* Tue Jul 24 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.6.20120403snap
- Rebuilt for hdf5 1.8.9
- Backport matio 1.5.0 support
- Use pkcon to provide help package on demand

* Tue May 15 2012 Orion Poplawski <orion@cora.nwra.com> - 5.4.0-0.5.20120403snap
- Rebuild for hdf5 1.8.9
- Add patch to build against matio 1.5.0

* Fri Apr 27 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.4.20120403snap
- rebuilt

* Tue Apr 03 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.3.20120403snap
- Add the arpack dependency

* Tue Apr 03 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.2.20120403snap
- Fix build after merge

* Tue Apr 03 2012 Clément David <c.david86@gmail.com> - 5.4.0-0.1.20120403snap
- Update to 5.4.0 nightly builds

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.3.3-10
- Rebuilt for c++ ABI breakage

* Fri Feb 10 2012 Clément David <c.david86@gmail.com> - 5.3.3-9
- Update classpath.xml due to the jhdf5 move.

* Fri Feb 10 2012 Petr Pisar <ppisar@redhat.com> - 5.3.3-8
- Rebuild against PCRE 8.30

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 5.3.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Jan  2 2012 Clément David <c.david86@gmail.com> - 5.3.3-6
- Update classpath.xml due to the flexdock move.

* Tue Nov 22 2011 Clément David <c.david86@gmail.com> - 5.3.3-5
- use %{_hdf5_version} to avoid runtime crash

* Thu Nov 17 2011 Clément David <c.david86@gmail.com> - 5.3.3-4
- use %{hdf5ver} to avoid runtime crash

* Wed Nov  9 2011 <c.david86@gmail.com> 5.3.3-3
- Remove dependency on atlas (need only lapack ABI)
- Use noarch package on doc and tests
- Remove ldconfig on post/postun
- add a default font for doc generation
- scilab does not depends on scilab-doc anymore

* Sun Oct 30 2011 <c.david86@gmail.com> 5.3.3-2
- Use rpm auto dependency
- add minimal versions for flexdock and jrosetta

* Sun Oct 30 2011 <c.david86@gmail.com> 5.3.3-1
- First package

